Effect

Enum Effect 

pub enum Effect {
    Normal = 0,
    Blood = 1,
    Fire = 2,
    Ice = 3,
    Reflect = 4,
    Reflects = 5,
    FireNoReburn = 20,
    FireBreath = 21,
    FireExplode = 22,
    PowerExplode = 23,
    Icicle = 30,
}
Itr effect variants.

See https://lf-empire.de/en/lf2-empire/data-changing/reference-pages/181-effects

Variants



Normal = 0

Normal, weapons fly away.

  • Sound: 001/006.wav.
  • Effect: Normal, weapons fly away.
  • Examples: Regular attacks.
  • **itrs **without any effect act like this.


Blood = 1

Blood, weapons fly away.

  • Sound: 032/033.wav.
  • Effect: Blood, weapons fly away.
  • Examples: Deep’s sword attacks.


Fire = 2

Fire, can hit burning characters, weapons fly away.

  • Sound: 070/071.wav.
  • Effect: Fire, can hit burning characters, weapons fly away.
  • Examples: Firen’s Firerun.


Ice = 3

Ice, can hit frozen characters, weapons fly away.

  • Sound: 065/066.wav.
  • Effect: Ice, can hit frozen characters, weapons fly away.
  • Examples: Ice Ball.


Reflect = 4

Reflect all flying attacks with state: 3000, weapons fly away, has no influence on other characters.

  • Sound: weapon_hit_sound.
  • Effect: Reflect all flying attacks with state: 3000, weapons fly away, has no influence on other characters.
  • Examples: “Shrafe” Attacks.


Reflects = 5

Reflects all flying attacks with state: 3000, weapons fly away, characters are hit without sound.

  • Sound: [no Sound].
  • Effect: Reflects all flying attacks with state: 3000, weapons. fly away, characters are hit without sound.
  • Examples: [Never used].


FireNoReburn = 20

Fire, burning characters are immune to effect: 20/21, weapons don’t fly away.

  • Sound: 070/071.wav.
  • Effect: Fire, burning characters are immune to effect 20/21, weapons don’t fly away.
  • Examples: “Fire” frames, Firen’s Ground-Fire.


FireBreath = 21

Fire, burning characters are immune to effect 20/21, weapons fly away, will not hit teammates when combined with state: 18.

  • Sound: 070/071.wav.
  • Effect: Fire, burning characters are immune to effect 20/21, weapons fly away, will not hit teammates when combined with state: 18.
  • Examples: Firen’s Inferno.


FireExplode = 22

Fire, can hit burning characters, weapons fly away, a positive dvx goes to the middle, will not hit teammates when combined with state: 18.

  • Sound: 070/071.wav.
  • Effect: Fire, can hit burning characters, weapons fly away, a. positive dvx goes to the middle, will not hit teammates when combined with state: 18
  • Examples: Firen’s Explosion.


PowerExplode = 23

Normal, character is hurtable, weapons fly away, a positive dvx goes to the middle.

  • Sound: 070/071.wav.
  • Effect: Normal, character is hurtable, weapons fly away, a. positive dvx goes to the middle
  • Examples: Julian’s Explosion.


Icicle = 30

Ice, frozen characters are immune to effect: 30, weapons fly away.

  • Sound: 065.wav.
  • Effect: Ice, frozen characters are immune to effect: 30, weapons. fly away.
  • Examples: Freeze Icicle.